@@ -11,7 +11,7 @@ from collections_extended import RangeMap
 from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.formatter import FormatterParameters, FormatterBase
 from pymultirole_plugins.v1.processor import ProcessorBase, ProcessorParameters
-from pymultirole_plugins.v1.schema import Document
+from pymultirole_plugins.v1.schema import Document, Sentence
 from spacy.cli.download import download_model, get_compatibility, get_version
 from spacy.errors import OLD_MODEL_SHORTCUTS
 from spacy.language import Language
@@ -128,12 +128,12 @@ class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
             num_sent += 1
             if num_sent == limit_sentences:
                 break
-        summary = '\n'.join(summary_sentences)
-        return summary
+        return summary_sentences
 
     def format(self, document: Document, parameters: FormatterParameters) \
             -> Response:
-        summary = self._summarize(document, parameters)
+        summary_sentences = self._summarize(document, parameters)
+        summary = '\n'.join(summary_sentences)
         return PlainTextResponse(summary)
 
     def process(self, documents: List[Document], parameters: ProcessorParameters) \
@@ -141,13 +141,20 @@ class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
         params: TextRankSummarizerParameters = \
             cast(TextRankSummarizerParameters, parameters)
         for document in documents:
-            summary = self._summarize(document, parameters)
+            summary_sentences = self._summarize(document, parameters)
             if params.as_metadata is not None and len(params.as_metadata):
                 if not document.metadata:
                     document.metadata = {}
-                document.metadata[params.as_metadata] = summary
+                document.metadata[params.as_metadata] = '\n'.join(summary_sentences)
             else:
-                document.text = summary
+                document.text = ""
+                document.sentences = []
+                for i, summary_sentence in enumerate(summary_sentences):
+                    last = i == len(summary_sentences) - 1
+                    start = len(document.text)
+                    end = start + len(summary_sentence)
+                    document.sentences.append(Sentence(start=start, end=end))
+                    document.text += summary_sentence + ("\n" if not last else "")
         return documents
 
     @classmethod
